
# Class: activity and behavior


Activity or behavior of any independent integral living, organization or mechanical actor in the world

URI: [biolink:ActivityAndBehavior](https://w3id.org/biolink/vocab/ActivityAndBehavior)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[Occurrent],[Procedure]uses%20-.->[ActivityAndBehavior],[Activity]uses%20-.->[ActivityAndBehavior],[Occurrent]^-[ActivityAndBehavior],[Procedure],[Activity])](https://yuml.me/diagram/nofunky;dir:TB/class/[Occurrent],[Procedure]uses%20-.->[ActivityAndBehavior],[Activity]uses%20-.->[ActivityAndBehavior],[Occurrent]^-[ActivityAndBehavior],[Procedure],[Activity])

## Parents

 *  is_a: [Occurrent](Occurrent.md) - A processual entity.

## Mixin for

 * [Activity](Activity.md) (mixin)  - An activity is something that occurs over a period of time and acts upon or with entities; it may include consuming, processing, transforming, modifying, relocating, using, or generating entities.
 * [Procedure](Procedure.md) (mixin)  - A series of actions conducted in a certain order or manner

## Referenced by Class


## Attributes


## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | UMLSSG:ACTI |

